@@ -9,7 +9,7 @@ namespace gl
 {
 
 
-enum class GLextension : int // GLextension is not a type introduced by OpenGL API so far
+enum class GLextension : int // GLextension is not a type introduced by GL API so far
 {
     UNKNOWN = -1,
     GL_3DFX_multisample,
@@ -20,6 +20,7 @@ enum class GLextension : int // GLextension is not a type introduced by OpenGL A
     GL_AMD_debug_output,
     GL_AMD_depth_clamp_separate,
     GL_AMD_draw_buffers_blend,
+    GL_AMD_framebuffer_multisample_advanced,
     GL_AMD_framebuffer_sample_positions,
     GL_AMD_gcn_shader,
     GL_AMD_gpu_shader_half_float,
@@ -66,10 +67,6 @@ enum class GLextension : int // GLextension is not a type introduced by OpenGL A
     GL_APPLE_vertex_array_range,
     GL_APPLE_vertex_program_evaluators,
     GL_APPLE_ycbcr_422,
-    GL_ARB_ES2_compatibility,
-    GL_ARB_ES3_1_compatibility,
-    GL_ARB_ES3_2_compatibility,
-    GL_ARB_ES3_compatibility,
     GL_ARB_arrays_of_arrays,
     GL_ARB_base_instance,
     GL_ARB_bindless_texture,
@@ -101,6 +98,10 @@ enum class GLextension : int // GLextension is not a type introduced by OpenGL A
     GL_ARB_draw_indirect,
     GL_ARB_draw_instanced,
     GL_ARB_enhanced_layouts,
+    GL_ARB_ES2_compatibility,
+    GL_ARB_ES3_1_compatibility,
+    GL_ARB_ES3_2_compatibility,
+    GL_ARB_ES3_compatibility,
     GL_ARB_explicit_attrib_location,
     GL_ARB_explicit_uniform_location,
     GL_ARB_fragment_coord_conventions,
@@ -278,9 +279,12 @@ enum class GLextension : int // GLextension is not a type introduced by OpenGL A
     GL_EXT_draw_buffers2,
     GL_EXT_draw_instanced,
     GL_EXT_draw_range_elements,
+    GL_EXT_EGL_image_storage,
+    GL_EXT_EGL_sync,
     GL_EXT_external_buffer,
     GL_EXT_fog_coord,
     GL_EXT_framebuffer_blit,
+    GL_EXT_framebuffer_blit_layers,
     GL_EXT_framebuffer_multisample,
     GL_EXT_framebuffer_multisample_blit_scaled,
     GL_EXT_framebuffer_object,
@@ -300,6 +304,9 @@ enum class GLextension : int // GLextension is not a type introduced by OpenGL A
     GL_EXT_misc_attribute,
     GL_EXT_multi_draw_arrays,
     GL_EXT_multisample,
+    GL_EXT_multiview_tessellation_geometry_shader,
+    GL_EXT_multiview_texture_multisample,
+    GL_EXT_multiview_timer_query,
     GL_EXT_packed_depth_stencil,
     GL_EXT_packed_float,
     GL_EXT_packed_pixels,
@@ -325,6 +332,7 @@ enum class GLextension : int // GLextension is not a type introduced by OpenGL A
     GL_EXT_shader_image_load_formatted,
     GL_EXT_shader_image_load_store,
     GL_EXT_shader_integer_mix,
+    GL_EXT_shader_samples_identical,
     GL_EXT_shadow_funcs,
     GL_EXT_shared_texture_palette,
     GL_EXT_sparse_texture2,
@@ -350,10 +358,14 @@ enum class GLextension : int // GLextension is not a type introduced by OpenGL A
     GL_EXT_texture_mirror_clamp,
     GL_EXT_texture_object,
     GL_EXT_texture_perturb_normal,
-    GL_EXT_texture_sRGB,
-    GL_EXT_texture_sRGB_decode,
+    GL_EXT_texture_shadow_lod,
     GL_EXT_texture_shared_exponent,
     GL_EXT_texture_snorm,
+    GL_EXT_texture_sRGB,
+    GL_EXT_texture_sRGB_decode,
+    GL_EXT_texture_sRGB_R8,
+    GL_EXT_texture_sRGB_RG8,
+    GL_EXT_texture_storage,
     GL_EXT_texture_swizzle,
     GL_EXT_timer_query,
     GL_EXT_transform_feedback,
@@ -380,6 +392,7 @@ enum class GLextension : int // GLextension is not a type introduced by OpenGL A
     GL_INGR_blend_func_separate,
     GL_INGR_color_clamp,
     GL_INGR_interlace_read,
+    GL_INTEL_blackhole_render,
     GL_INTEL_conservative_rasterization,
     GL_INTEL_fragment_shader_ordering,
     GL_INTEL_framebuffer_CMAA,
@@ -394,21 +407,22 @@ enum class GLextension : int // GLextension is not a type introduced by OpenGL A
     GL_KHR_parallel_shader_compile,
     GL_KHR_robust_buffer_access_behavior,
     GL_KHR_robustness,
+    GL_KHR_shader_subgroup,
     GL_KHR_texture_compression_astc_hdr,
     GL_KHR_texture_compression_astc_ldr,
     GL_KHR_texture_compression_astc_sliced_3d,
-    GL_MESAX_texture_stack,
+    GL_MESA_framebuffer_flip_x,
+    GL_MESA_framebuffer_flip_y,
+    GL_MESA_framebuffer_swap_xy,
     GL_MESA_pack_invert,
     GL_MESA_program_binary_formats,
     GL_MESA_resize_buffers,
     GL_MESA_shader_integer_functions,
+    GL_MESA_texture_const_bandwidth,
     GL_MESA_tile_raster_order,
     GL_MESA_window_pos,
     GL_MESA_ycbcr_texture,
-    GL_NVX_blend_equation_advanced_multi_draw_buffers,
-    GL_NVX_conditional_render,
-    GL_NVX_gpu_memory_info,
-    GL_NVX_linked_gpu_multicast,
+    GL_MESAX_texture_stack,
     GL_NV_alpha_to_coverage_dither_control,
     GL_NV_bindless_multi_draw_indirect,
     GL_NV_bindless_multi_draw_indirect_count,
@@ -420,6 +434,7 @@ enum class GLextension : int // GLextension is not a type introduced by OpenGL A
     GL_NV_clip_space_w_scaling,
     GL_NV_command_list,
     GL_NV_compute_program5,
+    GL_NV_compute_shader_derivatives,
     GL_NV_conditional_render,
     GL_NV_conservative_raster,
     GL_NV_conservative_raster_dilate,
@@ -444,6 +459,7 @@ enum class GLextension : int // GLextension is not a type introduced by OpenGL A
     GL_NV_fragment_program2,
     GL_NV_fragment_program4,
     GL_NV_fragment_program_option,
+    GL_NV_fragment_shader_barycentric,
     GL_NV_fragment_shader_interlock,
     GL_NV_framebuffer_mixed_samples,
     GL_NV_framebuffer_multisample_coverage,
@@ -458,6 +474,9 @@ enum class GLextension : int // GLextension is not a type introduced by OpenGL A
     GL_NV_half_float,
     GL_NV_internalformat_sample_query,
     GL_NV_light_max_exponent,
+    GL_NV_memory_attachment,
+    GL_NV_memory_object_sparse,
+    GL_NV_mesh_shader,
     GL_NV_multisample_coverage,
     GL_NV_multisample_filter_hint,
     GL_NV_occlusion_query,
@@ -470,13 +489,16 @@ enum class GLextension : int // GLextension is not a type introduced by OpenGL A
     GL_NV_point_sprite,
     GL_NV_present_video,
     GL_NV_primitive_restart,
+    GL_NV_primitive_shading_rate,
     GL_NV_query_resource,
     GL_NV_query_resource_tag,
     GL_NV_register_combiners,
     GL_NV_register_combiners2,
+    GL_NV_representative_fragment_test,
     GL_NV_robustness_video_memory_purge,
     GL_NV_sample_locations,
     GL_NV_sample_mask_override_coverage,
+    GL_NV_scissor_exclusive,
     GL_NV_shader_atomic_counters,
     GL_NV_shader_atomic_float,
     GL_NV_shader_atomic_float64,
@@ -485,8 +507,11 @@ enum class GLextension : int // GLextension is not a type introduced by OpenGL A
     GL_NV_shader_buffer_load,
     GL_NV_shader_buffer_store,
     GL_NV_shader_storage_buffer_object,
+    GL_NV_shader_subgroup_partitioned,
+    GL_NV_shader_texture_footprint,
     GL_NV_shader_thread_group,
     GL_NV_shader_thread_shuffle,
+    GL_NV_shading_rate_image,
     GL_NV_stereo_view_rendering,
     GL_NV_tessellation_program5,
     GL_NV_texgen_emboss,
@@ -501,10 +526,13 @@ enum class GLextension : int // GLextension is not a type introduced by OpenGL A
     GL_NV_texture_shader,
     GL_NV_texture_shader2,
     GL_NV_texture_shader3,
+    GL_NV_timeline_semaphore,
     GL_NV_transform_feedback,
     GL_NV_transform_feedback2,
+    GL_NV_uniform_buffer_std430_layout,
     GL_NV_uniform_buffer_unified_memory,
     GL_NV_vdpau_interop,
+    GL_NV_vdpau_interop2,
     GL_NV_vertex_array_range,
     GL_NV_vertex_array_range2,
     GL_NV_vertex_attrib_integer_64bit,
@@ -518,6 +546,12 @@ enum class GLextension : int // GLextension is not a type introduced by OpenGL A
     GL_NV_video_capture,
     GL_NV_viewport_array2,
     GL_NV_viewport_swizzle,
+    GL_NVX_blend_equation_advanced_multi_draw_buffers,
+    GL_NVX_conditional_render,
+    GL_NVX_gpu_memory_info,
+    GL_NVX_gpu_multicast2,
+    GL_NVX_linked_gpu_multicast,
+    GL_NVX_progress_fence,
     GL_OES_byte_coordinates,
     GL_OES_compressed_paletted_texture,
     GL_OES_fixed_point,
@@ -533,6 +567,9 @@ enum class GLextension : int // GLextension is not a type introduced by OpenGL A
     GL_PGI_vertex_hints,
     GL_REND_screen_coordinates,
     GL_S3_s3tc,
+    GL_SGI_color_matrix,
+    GL_SGI_color_table,
+    GL_SGI_texture_color_table,
     GL_SGIS_detail_texture,
     GL_SGIS_fog_function,
     GL_SGIS_generate_mipmap,
@@ -586,19 +623,17 @@ enum class GLextension : int // GLextension is not a type introduced by OpenGL A
     GL_SGIX_ycrcb,
     GL_SGIX_ycrcb_subsample,
     GL_SGIX_ycrcba,
-    GL_SGI_color_matrix,
-    GL_SGI_color_table,
-    GL_SGI_texture_color_table,
-    GL_SUNX_constant_data,
     GL_SUN_convolution_border_modes,
     GL_SUN_global_alpha,
     GL_SUN_mesh_array,
     GL_SUN_slice_accum,
     GL_SUN_triangle_list,
     GL_SUN_vertex,
+    GL_SUNX_constant_data,
     GL_WIN_phong_shading,
     GL_WIN_specular_fog
+    
 };
 
 
-} // namespace gl
+} // namespace gl
\ No newline at end of file
