@@ -11,10 +11,13 @@ namespace gl43
 {
 
 
-// import booleans to namespace
+// use boolean type
+using gl::GLboolean;
 
+
+// import booleans to namespace
 using gl::GL_FALSE;
 using gl::GL_TRUE;
 
 
-} // namespace gl43
+} // namespace gl43
\ No newline at end of file
