@@ -9,15 +9,10 @@
 namespace gl46
 {
 
-
-using gl::glAccum;
+// import functions
 using gl::glActiveShaderProgram;
 using gl::glActiveTexture;
-using gl::glAlphaFunc;
-using gl::glAreTexturesResident;
-using gl::glArrayElement;
 using gl::glAttachShader;
-using gl::glBegin;
 using gl::glBeginConditionalRender;
 using gl::glBeginQuery;
 using gl::glBeginQueryIndexed;
@@ -38,44 +33,39 @@ using gl::glBindRenderbuffer;
 using gl::glBindSampler;
 using gl::glBindSamplers;
 using gl::glBindTexture;
-using gl::glBindTextureUnit;
 using gl::glBindTextures;
+using gl::glBindTextureUnit;
 using gl::glBindTransformFeedback;
 using gl::glBindVertexArray;
 using gl::glBindVertexBuffer;
 using gl::glBindVertexBuffers;
-using gl::glBitmap;
 using gl::glBlendColor;
 using gl::glBlendEquation;
+using gl::glBlendEquationi;
 using gl::glBlendEquationSeparate;
 using gl::glBlendEquationSeparatei;
-using gl::glBlendEquationi;
 using gl::glBlendFunc;
+using gl::glBlendFunci;
 using gl::glBlendFuncSeparate;
 using gl::glBlendFuncSeparatei;
-using gl::glBlendFunci;
 using gl::glBlitFramebuffer;
 using gl::glBlitNamedFramebuffer;
 using gl::glBufferData;
 using gl::glBufferStorage;
 using gl::glBufferSubData;
-using gl::glCallList;
-using gl::glCallLists;
 using gl::glCheckFramebufferStatus;
 using gl::glCheckNamedFramebufferStatus;
 using gl::glClampColor;
 using gl::glClear;
-using gl::glClearAccum;
 using gl::glClearBufferData;
-using gl::glClearBufferSubData;
 using gl::glClearBufferfi;
 using gl::glClearBufferfv;
 using gl::glClearBufferiv;
+using gl::glClearBufferSubData;
 using gl::glClearBufferuiv;
 using gl::glClearColor;
 using gl::glClearDepth;
 using gl::glClearDepthf;
-using gl::glClearIndex;
 using gl::glClearNamedBufferData;
 using gl::glClearNamedBufferSubData;
 using gl::glClearNamedFramebufferfi;
@@ -85,50 +75,14 @@ using gl::glClearNamedFramebufferuiv;
 using gl::glClearStencil;
 using gl::glClearTexImage;
 using gl::glClearTexSubImage;
-using gl::glClientActiveTexture;
 using gl::glClientWaitSync;
 using gl::glClipControl;
-using gl::glClipPlane;
-using gl::glColor3b;
-using gl::glColor3bv;
-using gl::glColor3d;
-using gl::glColor3dv;
-using gl::glColor3f;
-using gl::glColor3fv;
-using gl::glColor3i;
-using gl::glColor3iv;
-using gl::glColor3s;
-using gl::glColor3sv;
-using gl::glColor3ub;
-using gl::glColor3ubv;
-using gl::glColor3ui;
-using gl::glColor3uiv;
-using gl::glColor3us;
-using gl::glColor3usv;
-using gl::glColor4b;
-using gl::glColor4bv;
-using gl::glColor4d;
-using gl::glColor4dv;
-using gl::glColor4f;
-using gl::glColor4fv;
-using gl::glColor4i;
-using gl::glColor4iv;
-using gl::glColor4s;
-using gl::glColor4sv;
-using gl::glColor4ub;
-using gl::glColor4ubv;
-using gl::glColor4ui;
-using gl::glColor4uiv;
-using gl::glColor4us;
-using gl::glColor4usv;
 using gl::glColorMask;
 using gl::glColorMaski;
-using gl::glColorMaterial;
 using gl::glColorP3ui;
 using gl::glColorP3uiv;
 using gl::glColorP4ui;
 using gl::glColorP4uiv;
-using gl::glColorPointer;
 using gl::glCompileShader;
 using gl::glCompressedTexImage1D;
 using gl::glCompressedTexImage2D;
@@ -142,7 +96,6 @@ using gl::glCompressedTextureSubImage3D;
 using gl::glCopyBufferSubData;
 using gl::glCopyImageSubData;
 using gl::glCopyNamedBufferSubData;
-using gl::glCopyPixels;
 using gl::glCopyTexImage1D;
 using gl::glCopyTexImage2D;
 using gl::glCopyTexSubImage1D;
@@ -169,7 +122,6 @@ using gl::glDebugMessageControl;
 using gl::glDebugMessageInsert;
 using gl::glDeleteBuffers;
 using gl::glDeleteFramebuffers;
-using gl::glDeleteLists;
 using gl::glDeleteProgram;
 using gl::glDeleteProgramPipelines;
 using gl::glDeleteQueries;
@@ -184,14 +136,13 @@ using gl::glDepthFunc;
 using gl::glDepthMask;
 using gl::glDepthRange;
 using gl::glDepthRangeArrayv;
-using gl::glDepthRangeIndexed;
 using gl::glDepthRangef;
+using gl::glDepthRangeIndexed;
 using gl::glDetachShader;
 using gl::glDisable;
-using gl::glDisableClientState;
+using gl::glDisablei;
 using gl::glDisableVertexArrayAttrib;
 using gl::glDisableVertexAttribArray;
-using gl::glDisablei;
 using gl::glDispatchCompute;
 using gl::glDispatchComputeIndirect;
 using gl::glDrawArrays;
@@ -207,54 +158,25 @@ using gl::glDrawElementsInstanced;
 using gl::glDrawElementsInstancedBaseInstance;
 using gl::glDrawElementsInstancedBaseVertex;
 using gl::glDrawElementsInstancedBaseVertexBaseInstance;
-using gl::glDrawPixels;
 using gl::glDrawRangeElements;
 using gl::glDrawRangeElementsBaseVertex;
 using gl::glDrawTransformFeedback;
 using gl::glDrawTransformFeedbackInstanced;
 using gl::glDrawTransformFeedbackStream;
 using gl::glDrawTransformFeedbackStreamInstanced;
-using gl::glEdgeFlag;
-using gl::glEdgeFlagPointer;
-using gl::glEdgeFlagv;
 using gl::glEnable;
-using gl::glEnableClientState;
+using gl::glEnablei;
 using gl::glEnableVertexArrayAttrib;
 using gl::glEnableVertexAttribArray;
-using gl::glEnablei;
-using gl::glEnd;
 using gl::glEndConditionalRender;
-using gl::glEndList;
 using gl::glEndQuery;
 using gl::glEndQueryIndexed;
 using gl::glEndTransformFeedback;
-using gl::glEvalCoord1d;
-using gl::glEvalCoord1dv;
-using gl::glEvalCoord1f;
-using gl::glEvalCoord1fv;
-using gl::glEvalCoord2d;
-using gl::glEvalCoord2dv;
-using gl::glEvalCoord2f;
-using gl::glEvalCoord2fv;
-using gl::glEvalMesh1;
-using gl::glEvalMesh2;
-using gl::glEvalPoint1;
-using gl::glEvalPoint2;
-using gl::glFeedbackBuffer;
 using gl::glFenceSync;
 using gl::glFinish;
 using gl::glFlush;
 using gl::glFlushMappedBufferRange;
 using gl::glFlushMappedNamedBufferRange;
-using gl::glFogCoordPointer;
-using gl::glFogCoordd;
-using gl::glFogCoorddv;
-using gl::glFogCoordf;
-using gl::glFogCoordfv;
-using gl::glFogf;
-using gl::glFogfv;
-using gl::glFogi;
-using gl::glFogiv;
 using gl::glFramebufferParameteri;
 using gl::glFramebufferRenderbuffer;
 using gl::glFramebufferTexture;
@@ -263,10 +185,10 @@ using gl::glFramebufferTexture2D;
 using gl::glFramebufferTexture3D;
 using gl::glFramebufferTextureLayer;
 using gl::glFrontFace;
-using gl::glFrustum;
 using gl::glGenBuffers;
+using gl::glGenerateMipmap;
+using gl::glGenerateTextureMipmap;
 using gl::glGenFramebuffers;
-using gl::glGenLists;
 using gl::glGenProgramPipelines;
 using gl::glGenQueries;
 using gl::glGenRenderbuffers;
@@ -274,16 +196,14 @@ using gl::glGenSamplers;
 using gl::glGenTextures;
 using gl::glGenTransformFeedbacks;
 using gl::glGenVertexArrays;
-using gl::glGenerateMipmap;
-using gl::glGenerateTextureMipmap;
 using gl::glGetActiveAtomicCounterBufferiv;
 using gl::glGetActiveAttrib;
 using gl::glGetActiveSubroutineName;
-using gl::glGetActiveSubroutineUniformName;
 using gl::glGetActiveSubroutineUniformiv;
+using gl::glGetActiveSubroutineUniformName;
 using gl::glGetActiveUniform;
-using gl::glGetActiveUniformBlockName;
 using gl::glGetActiveUniformBlockiv;
+using gl::glGetActiveUniformBlockName;
 using gl::glGetActiveUniformName;
 using gl::glGetActiveUniformsiv;
 using gl::glGetAttachedShaders;
@@ -294,7 +214,6 @@ using gl::glGetBufferParameteri64v;
 using gl::glGetBufferParameteriv;
 using gl::glGetBufferPointerv;
 using gl::glGetBufferSubData;
-using gl::glGetClipPlane;
 using gl::glGetCompressedTexImage;
 using gl::glGetCompressedTextureImage;
 using gl::glGetCompressedTextureSubImage;
@@ -315,13 +234,6 @@ using gl::glGetIntegeri_v;
 using gl::glGetIntegerv;
 using gl::glGetInternalformati64v;
 using gl::glGetInternalformativ;
-using gl::glGetLightfv;
-using gl::glGetLightiv;
-using gl::glGetMapdv;
-using gl::glGetMapfv;
-using gl::glGetMapiv;
-using gl::glGetMaterialfv;
-using gl::glGetMaterialiv;
 using gl::glGetMultisamplefv;
 using gl::glGetNamedBufferParameteri64v;
 using gl::glGetNamedBufferParameteriv;
@@ -330,91 +242,6 @@ using gl::glGetNamedBufferSubData;
 using gl::glGetNamedFramebufferAttachmentParameteriv;
 using gl::glGetNamedFramebufferParameteriv;
 using gl::glGetNamedRenderbufferParameteriv;
-using gl::glGetObjectLabel;
-using gl::glGetObjectPtrLabel;
-using gl::glGetPixelMapfv;
-using gl::glGetPixelMapuiv;
-using gl::glGetPixelMapusv;
-using gl::glGetPointerv;
-using gl::glGetPolygonStipple;
-using gl::glGetProgramBinary;
-using gl::glGetProgramInfoLog;
-using gl::glGetProgramInterfaceiv;
-using gl::glGetProgramPipelineInfoLog;
-using gl::glGetProgramPipelineiv;
-using gl::glGetProgramResourceIndex;
-using gl::glGetProgramResourceLocation;
-using gl::glGetProgramResourceLocationIndex;
-using gl::glGetProgramResourceName;
-using gl::glGetProgramResourceiv;
-using gl::glGetProgramStageiv;
-using gl::glGetProgramiv;
-using gl::glGetQueryBufferObjecti64v;
-using gl::glGetQueryBufferObjectiv;
-using gl::glGetQueryBufferObjectui64v;
-using gl::glGetQueryBufferObjectuiv;
-using gl::glGetQueryIndexediv;
-using gl::glGetQueryObjecti64v;
-using gl::glGetQueryObjectiv;
-using gl::glGetQueryObjectui64v;
-using gl::glGetQueryObjectuiv;
-using gl::glGetQueryiv;
-using gl::glGetRenderbufferParameteriv;
-using gl::glGetSamplerParameterIiv;
-using gl::glGetSamplerParameterIuiv;
-using gl::glGetSamplerParameterfv;
-using gl::glGetSamplerParameteriv;
-using gl::glGetShaderInfoLog;
-using gl::glGetShaderPrecisionFormat;
-using gl::glGetShaderSource;
-using gl::glGetShaderiv;
-using gl::glGetString;
-using gl::glGetStringi;
-using gl::glGetSubroutineIndex;
-using gl::glGetSubroutineUniformLocation;
-using gl::glGetSynciv;
-using gl::glGetTexEnvfv;
-using gl::glGetTexEnviv;
-using gl::glGetTexGendv;
-using gl::glGetTexGenfv;
-using gl::glGetTexGeniv;
-using gl::glGetTexImage;
-using gl::glGetTexLevelParameterfv;
-using gl::glGetTexLevelParameteriv;
-using gl::glGetTexParameterIiv;
-using gl::glGetTexParameterIuiv;
-using gl::glGetTexParameterfv;
-using gl::glGetTexParameteriv;
-using gl::glGetTextureImage;
-using gl::glGetTextureLevelParameterfv;
-using gl::glGetTextureLevelParameteriv;
-using gl::glGetTextureParameterIiv;
-using gl::glGetTextureParameterIuiv;
-using gl::glGetTextureParameterfv;
-using gl::glGetTextureParameteriv;
-using gl::glGetTextureSubImage;
-using gl::glGetTransformFeedbackVarying;
-using gl::glGetTransformFeedbacki64_v;
-using gl::glGetTransformFeedbacki_v;
-using gl::glGetTransformFeedbackiv;
-using gl::glGetUniformBlockIndex;
-using gl::glGetUniformIndices;
-using gl::glGetUniformLocation;
-using gl::glGetUniformSubroutineuiv;
-using gl::glGetUniformdv;
-using gl::glGetUniformfv;
-using gl::glGetUniformiv;
-using gl::glGetUniformuiv;
-using gl::glGetVertexArrayIndexed64iv;
-using gl::glGetVertexArrayIndexediv;
-using gl::glGetVertexArrayiv;
-using gl::glGetVertexAttribIiv;
-using gl::glGetVertexAttribIuiv;
-using gl::glGetVertexAttribLdv;
-using gl::glGetVertexAttribPointerv;
-using gl::glGetVertexAttribdv;
-using gl::glGetVertexAttribfv;
-using gl::glGetVertexAttribiv;
 using gl::glGetnColorTable;
 using gl::glGetnCompressedTexImage;
 using gl::glGetnConvolutionFilter;
@@ -433,21 +260,83 @@ using gl::glGetnUniformdv;
 using gl::glGetnUniformfv;
 using gl::glGetnUniformiv;
 using gl::glGetnUniformuiv;
+using gl::glGetObjectLabel;
+using gl::glGetObjectPtrLabel;
+using gl::glGetPointerv;
+using gl::glGetProgramBinary;
+using gl::glGetProgramInfoLog;
+using gl::glGetProgramInterfaceiv;
+using gl::glGetProgramiv;
+using gl::glGetProgramPipelineInfoLog;
+using gl::glGetProgramPipelineiv;
+using gl::glGetProgramResourceIndex;
+using gl::glGetProgramResourceiv;
+using gl::glGetProgramResourceLocation;
+using gl::glGetProgramResourceLocationIndex;
+using gl::glGetProgramResourceName;
+using gl::glGetProgramStageiv;
+using gl::glGetQueryBufferObjecti64v;
+using gl::glGetQueryBufferObjectiv;
+using gl::glGetQueryBufferObjectui64v;
+using gl::glGetQueryBufferObjectuiv;
+using gl::glGetQueryIndexediv;
+using gl::glGetQueryiv;
+using gl::glGetQueryObjecti64v;
+using gl::glGetQueryObjectiv;
+using gl::glGetQueryObjectui64v;
+using gl::glGetQueryObjectuiv;
+using gl::glGetRenderbufferParameteriv;
+using gl::glGetSamplerParameterfv;
+using gl::glGetSamplerParameterIiv;
+using gl::glGetSamplerParameterIuiv;
+using gl::glGetSamplerParameteriv;
+using gl::glGetShaderInfoLog;
+using gl::glGetShaderiv;
+using gl::glGetShaderPrecisionFormat;
+using gl::glGetShaderSource;
+using gl::glGetString;
+using gl::glGetStringi;
+using gl::glGetSubroutineIndex;
+using gl::glGetSubroutineUniformLocation;
+using gl::glGetSynciv;
+using gl::glGetTexImage;
+using gl::glGetTexLevelParameterfv;
+using gl::glGetTexLevelParameteriv;
+using gl::glGetTexParameterfv;
+using gl::glGetTexParameterIiv;
+using gl::glGetTexParameterIuiv;
+using gl::glGetTexParameteriv;
+using gl::glGetTextureImage;
+using gl::glGetTextureLevelParameterfv;
+using gl::glGetTextureLevelParameteriv;
+using gl::glGetTextureParameterfv;
+using gl::glGetTextureParameterIiv;
+using gl::glGetTextureParameterIuiv;
+using gl::glGetTextureParameteriv;
+using gl::glGetTextureSubImage;
+using gl::glGetTransformFeedbacki64_v;
+using gl::glGetTransformFeedbacki_v;
+using gl::glGetTransformFeedbackiv;
+using gl::glGetTransformFeedbackVarying;
+using gl::glGetUniformBlockIndex;
+using gl::glGetUniformdv;
+using gl::glGetUniformfv;
+using gl::glGetUniformIndices;
+using gl::glGetUniformiv;
+using gl::glGetUniformLocation;
+using gl::glGetUniformSubroutineuiv;
+using gl::glGetUniformuiv;
+using gl::glGetVertexArrayIndexed64iv;
+using gl::glGetVertexArrayIndexediv;
+using gl::glGetVertexArrayiv;
+using gl::glGetVertexAttribdv;
+using gl::glGetVertexAttribfv;
+using gl::glGetVertexAttribIiv;
+using gl::glGetVertexAttribIuiv;
+using gl::glGetVertexAttribiv;
+using gl::glGetVertexAttribLdv;
+using gl::glGetVertexAttribPointerv;
 using gl::glHint;
-using gl::glIndexMask;
-using gl::glIndexPointer;
-using gl::glIndexd;
-using gl::glIndexdv;
-using gl::glIndexf;
-using gl::glIndexfv;
-using gl::glIndexi;
-using gl::glIndexiv;
-using gl::glIndexs;
-using gl::glIndexsv;
-using gl::glIndexub;
-using gl::glIndexubv;
-using gl::glInitNames;
-using gl::glInterleavedArrays;
 using gl::glInvalidateBufferData;
 using gl::glInvalidateBufferSubData;
 using gl::glInvalidateFramebuffer;
@@ -460,7 +349,6 @@ using gl::glIsBuffer;
 using gl::glIsEnabled;
 using gl::glIsEnabledi;
 using gl::glIsFramebuffer;
-using gl::glIsList;
 using gl::glIsProgram;
 using gl::glIsProgramPipeline;
 using gl::glIsQuery;
@@ -471,49 +359,16 @@ using gl::glIsSync;
 using gl::glIsTexture;
 using gl::glIsTransformFeedback;
 using gl::glIsVertexArray;
-using gl::glLightModelf;
-using gl::glLightModelfv;
-using gl::glLightModeli;
-using gl::glLightModeliv;
-using gl::glLightf;
-using gl::glLightfv;
-using gl::glLighti;
-using gl::glLightiv;
-using gl::glLineStipple;
 using gl::glLineWidth;
 using gl::glLinkProgram;
-using gl::glListBase;
-using gl::glLoadIdentity;
-using gl::glLoadMatrixd;
-using gl::glLoadMatrixf;
-using gl::glLoadName;
-using gl::glLoadTransposeMatrixd;
-using gl::glLoadTransposeMatrixf;
 using gl::glLogicOp;
-using gl::glMap1d;
-using gl::glMap1f;
-using gl::glMap2d;
-using gl::glMap2f;
 using gl::glMapBuffer;
 using gl::glMapBufferRange;
-using gl::glMapGrid1d;
-using gl::glMapGrid1f;
-using gl::glMapGrid2d;
-using gl::glMapGrid2f;
 using gl::glMapNamedBuffer;
 using gl::glMapNamedBufferRange;
-using gl::glMaterialf;
-using gl::glMaterialfv;
-using gl::glMateriali;
-using gl::glMaterialiv;
-using gl::glMatrixMode;
 using gl::glMemoryBarrier;
 using gl::glMemoryBarrierByRegion;
 using gl::glMinSampleShading;
-using gl::glMultMatrixd;
-using gl::glMultMatrixf;
-using gl::glMultTransposeMatrixd;
-using gl::glMultTransposeMatrixf;
 using gl::glMultiDrawArrays;
 using gl::glMultiDrawArraysIndirect;
 using gl::glMultiDrawArraysIndirectCount;
@@ -521,38 +376,6 @@ using gl::glMultiDrawElements;
 using gl::glMultiDrawElementsBaseVertex;
 using gl::glMultiDrawElementsIndirect;
 using gl::glMultiDrawElementsIndirectCount;
-using gl::glMultiTexCoord1d;
-using gl::glMultiTexCoord1dv;
-using gl::glMultiTexCoord1f;
-using gl::glMultiTexCoord1fv;
-using gl::glMultiTexCoord1i;
-using gl::glMultiTexCoord1iv;
-using gl::glMultiTexCoord1s;
-using gl::glMultiTexCoord1sv;
-using gl::glMultiTexCoord2d;
-using gl::glMultiTexCoord2dv;
-using gl::glMultiTexCoord2f;
-using gl::glMultiTexCoord2fv;
-using gl::glMultiTexCoord2i;
-using gl::glMultiTexCoord2iv;
-using gl::glMultiTexCoord2s;
-using gl::glMultiTexCoord2sv;
-using gl::glMultiTexCoord3d;
-using gl::glMultiTexCoord3dv;
-using gl::glMultiTexCoord3f;
-using gl::glMultiTexCoord3fv;
-using gl::glMultiTexCoord3i;
-using gl::glMultiTexCoord3iv;
-using gl::glMultiTexCoord3s;
-using gl::glMultiTexCoord3sv;
-using gl::glMultiTexCoord4d;
-using gl::glMultiTexCoord4dv;
-using gl::glMultiTexCoord4f;
-using gl::glMultiTexCoord4fv;
-using gl::glMultiTexCoord4i;
-using gl::glMultiTexCoord4iv;
-using gl::glMultiTexCoord4s;
-using gl::glMultiTexCoord4sv;
 using gl::glMultiTexCoordP1ui;
 using gl::glMultiTexCoordP1uiv;
 using gl::glMultiTexCoordP2ui;
@@ -573,35 +396,15 @@ using gl::glNamedFramebufferTexture;
 using gl::glNamedFramebufferTextureLayer;
 using gl::glNamedRenderbufferStorage;
 using gl::glNamedRenderbufferStorageMultisample;
-using gl::glNewList;
-using gl::glNormal3b;
-using gl::glNormal3bv;
-using gl::glNormal3d;
-using gl::glNormal3dv;
-using gl::glNormal3f;
-using gl::glNormal3fv;
-using gl::glNormal3i;
-using gl::glNormal3iv;
-using gl::glNormal3s;
-using gl::glNormal3sv;
 using gl::glNormalP3ui;
 using gl::glNormalP3uiv;
-using gl::glNormalPointer;
 using gl::glObjectLabel;
 using gl::glObjectPtrLabel;
-using gl::glOrtho;
-using gl::glPassThrough;
 using gl::glPatchParameterfv;
 using gl::glPatchParameteri;
 using gl::glPauseTransformFeedback;
-using gl::glPixelMapfv;
-using gl::glPixelMapuiv;
-using gl::glPixelMapusv;
 using gl::glPixelStoref;
 using gl::glPixelStorei;
-using gl::glPixelTransferf;
-using gl::glPixelTransferi;
-using gl::glPixelZoom;
 using gl::glPointParameterf;
 using gl::glPointParameterfv;
 using gl::glPointParameteri;
@@ -610,14 +413,8 @@ using gl::glPointSize;
 using gl::glPolygonMode;
 using gl::glPolygonOffset;
 using gl::glPolygonOffsetClamp;
-using gl::glPolygonStipple;
-using gl::glPopAttrib;
-using gl::glPopClientAttrib;
 using gl::glPopDebugGroup;
-using gl::glPopMatrix;
-using gl::glPopName;
 using gl::glPrimitiveRestartIndex;
-using gl::glPrioritizeTextures;
 using gl::glProgramBinary;
 using gl::glProgramParameteri;
 using gl::glProgramUniform1d;
@@ -671,89 +468,29 @@ using gl::glProgramUniformMatrix4x2fv;
 using gl::glProgramUniformMatrix4x3dv;
 using gl::glProgramUniformMatrix4x3fv;
 using gl::glProvokingVertex;
-using gl::glPushAttrib;
-using gl::glPushClientAttrib;
 using gl::glPushDebugGroup;
-using gl::glPushMatrix;
-using gl::glPushName;
 using gl::glQueryCounter;
-using gl::glRasterPos2d;
-using gl::glRasterPos2dv;
-using gl::glRasterPos2f;
-using gl::glRasterPos2fv;
-using gl::glRasterPos2i;
-using gl::glRasterPos2iv;
-using gl::glRasterPos2s;
-using gl::glRasterPos2sv;
-using gl::glRasterPos3d;
-using gl::glRasterPos3dv;
-using gl::glRasterPos3f;
-using gl::glRasterPos3fv;
-using gl::glRasterPos3i;
-using gl::glRasterPos3iv;
-using gl::glRasterPos3s;
-using gl::glRasterPos3sv;
-using gl::glRasterPos4d;
-using gl::glRasterPos4dv;
-using gl::glRasterPos4f;
-using gl::glRasterPos4fv;
-using gl::glRasterPos4i;
-using gl::glRasterPos4iv;
-using gl::glRasterPos4s;
-using gl::glRasterPos4sv;
 using gl::glReadBuffer;
-using gl::glReadPixels;
 using gl::glReadnPixels;
-using gl::glRectd;
-using gl::glRectdv;
-using gl::glRectf;
-using gl::glRectfv;
-using gl::glRecti;
-using gl::glRectiv;
-using gl::glRects;
-using gl::glRectsv;
+using gl::glReadPixels;
 using gl::glReleaseShaderCompiler;
-using gl::glRenderMode;
 using gl::glRenderbufferStorage;
 using gl::glRenderbufferStorageMultisample;
 using gl::glResumeTransformFeedback;
-using gl::glRotated;
-using gl::glRotatef;
 using gl::glSampleCoverage;
 using gl::glSampleMaski;
-using gl::glSamplerParameterIiv;
-using gl::glSamplerParameterIuiv;
 using gl::glSamplerParameterf;
 using gl::glSamplerParameterfv;
 using gl::glSamplerParameteri;
+using gl::glSamplerParameterIiv;
+using gl::glSamplerParameterIuiv;
 using gl::glSamplerParameteriv;
-using gl::glScaled;
-using gl::glScalef;
 using gl::glScissor;
 using gl::glScissorArrayv;
 using gl::glScissorIndexed;
 using gl::glScissorIndexedv;
-using gl::glSecondaryColor3b;
-using gl::glSecondaryColor3bv;
-using gl::glSecondaryColor3d;
-using gl::glSecondaryColor3dv;
-using gl::glSecondaryColor3f;
-using gl::glSecondaryColor3fv;
-using gl::glSecondaryColor3i;
-using gl::glSecondaryColor3iv;
-using gl::glSecondaryColor3s;
-using gl::glSecondaryColor3sv;
-using gl::glSecondaryColor3ub;
-using gl::glSecondaryColor3ubv;
-using gl::glSecondaryColor3ui;
-using gl::glSecondaryColor3uiv;
-using gl::glSecondaryColor3us;
-using gl::glSecondaryColor3usv;
 using gl::glSecondaryColorP3ui;
 using gl::glSecondaryColorP3uiv;
-using gl::glSecondaryColorPointer;
-using gl::glSelectBuffer;
-using gl::glShadeModel;
 using gl::glShaderBinary;
 using gl::glShaderSource;
 using gl::glShaderStorageBlockBinding;
@@ -766,38 +503,6 @@ using gl::glStencilOp;
 using gl::glStencilOpSeparate;
 using gl::glTexBuffer;
 using gl::glTexBufferRange;
-using gl::glTexCoord1d;
-using gl::glTexCoord1dv;
-using gl::glTexCoord1f;
-using gl::glTexCoord1fv;
-using gl::glTexCoord1i;
-using gl::glTexCoord1iv;
-using gl::glTexCoord1s;
-using gl::glTexCoord1sv;
-using gl::glTexCoord2d;
-using gl::glTexCoord2dv;
-using gl::glTexCoord2f;
-using gl::glTexCoord2fv;
-using gl::glTexCoord2i;
-using gl::glTexCoord2iv;
-using gl::glTexCoord2s;
-using gl::glTexCoord2sv;
-using gl::glTexCoord3d;
-using gl::glTexCoord3dv;
-using gl::glTexCoord3f;
-using gl::glTexCoord3fv;
-using gl::glTexCoord3i;
-using gl::glTexCoord3iv;
-using gl::glTexCoord3s;
-using gl::glTexCoord3sv;
-using gl::glTexCoord4d;
-using gl::glTexCoord4dv;
-using gl::glTexCoord4f;
-using gl::glTexCoord4fv;
-using gl::glTexCoord4i;
-using gl::glTexCoord4iv;
-using gl::glTexCoord4s;
-using gl::glTexCoord4sv;
 using gl::glTexCoordP1ui;
 using gl::glTexCoordP1uiv;
 using gl::glTexCoordP2ui;
@@ -806,27 +511,16 @@ using gl::glTexCoordP3ui;
 using gl::glTexCoordP3uiv;
 using gl::glTexCoordP4ui;
 using gl::glTexCoordP4uiv;
-using gl::glTexCoordPointer;
-using gl::glTexEnvf;
-using gl::glTexEnvfv;
-using gl::glTexEnvi;
-using gl::glTexEnviv;
-using gl::glTexGend;
-using gl::glTexGendv;
-using gl::glTexGenf;
-using gl::glTexGenfv;
-using gl::glTexGeni;
-using gl::glTexGeniv;
 using gl::glTexImage1D;
 using gl::glTexImage2D;
 using gl::glTexImage2DMultisample;
 using gl::glTexImage3D;
 using gl::glTexImage3DMultisample;
-using gl::glTexParameterIiv;
-using gl::glTexParameterIuiv;
 using gl::glTexParameterf;
 using gl::glTexParameterfv;
 using gl::glTexParameteri;
+using gl::glTexParameterIiv;
+using gl::glTexParameterIuiv;
 using gl::glTexParameteriv;
 using gl::glTexStorage1D;
 using gl::glTexStorage2D;
@@ -839,11 +533,11 @@ using gl::glTexSubImage3D;
 using gl::glTextureBarrier;
 using gl::glTextureBuffer;
 using gl::glTextureBufferRange;
-using gl::glTextureParameterIiv;
-using gl::glTextureParameterIuiv;
 using gl::glTextureParameterf;
 using gl::glTextureParameterfv;
 using gl::glTextureParameteri;
+using gl::glTextureParameterIiv;
+using gl::glTextureParameterIuiv;
 using gl::glTextureParameteriv;
 using gl::glTextureStorage1D;
 using gl::glTextureStorage2D;
@@ -857,8 +551,6 @@ using gl::glTextureView;
 using gl::glTransformFeedbackBufferBase;
 using gl::glTransformFeedbackBufferRange;
 using gl::glTransformFeedbackVaryings;
-using gl::glTranslated;
-using gl::glTranslatef;
 using gl::glUniform1d;
 using gl::glUniform1dv;
 using gl::glUniform1f;
@@ -917,30 +609,6 @@ using gl::glUseProgram;
 using gl::glUseProgramStages;
 using gl::glValidateProgram;
 using gl::glValidateProgramPipeline;
-using gl::glVertex2d;
-using gl::glVertex2dv;
-using gl::glVertex2f;
-using gl::glVertex2fv;
-using gl::glVertex2i;
-using gl::glVertex2iv;
-using gl::glVertex2s;
-using gl::glVertex2sv;
-using gl::glVertex3d;
-using gl::glVertex3dv;
-using gl::glVertex3f;
-using gl::glVertex3fv;
-using gl::glVertex3i;
-using gl::glVertex3iv;
-using gl::glVertex3s;
-using gl::glVertex3sv;
-using gl::glVertex4d;
-using gl::glVertex4dv;
-using gl::glVertex4f;
-using gl::glVertex4fv;
-using gl::glVertex4i;
-using gl::glVertex4iv;
-using gl::glVertex4s;
-using gl::glVertex4sv;
 using gl::glVertexArrayAttribBinding;
 using gl::glVertexArrayAttribFormat;
 using gl::glVertexArrayAttribIFormat;
@@ -967,6 +635,12 @@ using gl::glVertexAttrib3f;
 using gl::glVertexAttrib3fv;
 using gl::glVertexAttrib3s;
 using gl::glVertexAttrib3sv;
+using gl::glVertexAttrib4bv;
+using gl::glVertexAttrib4d;
+using gl::glVertexAttrib4dv;
+using gl::glVertexAttrib4f;
+using gl::glVertexAttrib4fv;
+using gl::glVertexAttrib4iv;
 using gl::glVertexAttrib4Nbv;
 using gl::glVertexAttrib4Niv;
 using gl::glVertexAttrib4Nsv;
@@ -974,12 +648,6 @@ using gl::glVertexAttrib4Nub;
 using gl::glVertexAttrib4Nubv;
 using gl::glVertexAttrib4Nuiv;
 using gl::glVertexAttrib4Nusv;
-using gl::glVertexAttrib4bv;
-using gl::glVertexAttrib4d;
-using gl::glVertexAttrib4dv;
-using gl::glVertexAttrib4f;
-using gl::glVertexAttrib4fv;
-using gl::glVertexAttrib4iv;
 using gl::glVertexAttrib4s;
 using gl::glVertexAttrib4sv;
 using gl::glVertexAttrib4ubv;
@@ -1036,28 +704,10 @@ using gl::glVertexP3ui;
 using gl::glVertexP3uiv;
 using gl::glVertexP4ui;
 using gl::glVertexP4uiv;
-using gl::glVertexPointer;
 using gl::glViewport;
 using gl::glViewportArrayv;
 using gl::glViewportIndexedf;
 using gl::glViewportIndexedfv;
 using gl::glWaitSync;
-using gl::glWindowPos2d;
-using gl::glWindowPos2dv;
-using gl::glWindowPos2f;
-using gl::glWindowPos2fv;
-using gl::glWindowPos2i;
-using gl::glWindowPos2iv;
-using gl::glWindowPos2s;
-using gl::glWindowPos2sv;
-using gl::glWindowPos3d;
-using gl::glWindowPos3dv;
-using gl::glWindowPos3f;
-using gl::glWindowPos3fv;
-using gl::glWindowPos3i;
-using gl::glWindowPos3iv;
-using gl::glWindowPos3s;
-using gl::glWindowPos3sv;
 
-
-} // namespace gl46
+} // namespace gl46
\ No newline at end of file
