@@ -25,7 +25,7 @@ class FunctionCall;
 
 using SimpleFunctionCallback = std::function<void(const AbstractFunction &)>; ///< The signature of the unresolved callback
 using FunctionCallback = std::function<void(const FunctionCall &)>;           ///< The signature of the before and after callbacks
-using FunctionLogCallback = std::function<void(FunctionCall *)>;              ///< The signature of the log callback
+using FunctionLogCallback = std::function<void(FunctionCall &&)>;             ///< The signature of the log callback
 using ContextSwitchCallback = std::function<void(ContextHandle)>;             ///< The signature of the context switch callback
 
 /**
@@ -39,6 +39,11 @@ using ContextSwitchCallback = std::function<void(ContextHandle)>;             //
 *    Whether to resolve function pointers lazily (\a resolveFunctions = `false`) or immediately
 *
 *  @remark
+*    This function is a convenience interface for applications that use only one OpenGL context.
+*    If you want to use more than one context, use explicit context identifiers and the dedicated
+*    Initialization interface initialize(ContextHandle, glbinding::GetProcAddress, bool, bool).
+*
+*  @remark
 *    After this call, the initialized context is already set active for the current thread.
 *
 *  @remark
@@ -55,6 +60,61 @@ using ContextSwitchCallback = std::function<void(ContextHandle)>;             //
 */
 GLBINDING_API void initialize(glbinding::GetProcAddress functionPointerResolver, bool resolveFunctions = true);
 
+/**
+*  @brief
+*    Initializes the binding for the current active OpenGL context
+*
+*  @param[in] context
+*    The context handle of the context to initialize
+*  @param[in] functionPointerResolver
+*    A function pointer to resolve binding functions for this context
+*  @param[in] useContext
+*    Whether to set the context active (\a useContext = `true`) after the initialization
+*  @param[in] resolveFunctions (optional)
+*    Whether to resolve function pointers lazily (\a resolveFunctions = `false`) or immediately
+*
+*  @remark
+*    A functionPointerResolver with value 'nullptr' will get initialized with the function
+*    pointer from the initial thread.
+*/
+GLBINDING_API void initialize(ContextHandle context, glbinding::GetProcAddress functionPointerResolver, bool useContext = true, bool resolveFunctions = true);
+
+/**
+*  @brief
+*    Update the current context state in glbinding
+*
+*  @remark
+*    This function queries the driver for the current OpenGL context
+*/
+GLBINDING_API void useCurrentContext();
+
+/**
+*  @brief
+*    Update the current context state in glbinding
+*
+*  @param[in] context
+*    The context handle of the context to set current
+*/
+GLBINDING_API void useContext(ContextHandle context);
+
+/**
+*  @brief
+*    Removes the current context from the state of glbinding
+*
+*  @remark
+*    This function queries the driver for the current OpenGL context
+*/
+GLBINDING_API void releaseCurrentContext();
+
+/**
+*  @brief
+*    Removes the current context from the state of glbinding
+*
+*  @param[in] context
+*    The context handle of the context to remove
+*/
+GLBINDING_API void releaseContext(ContextHandle context);
+
 /**
 *  @brief
 *    Registers an additional function for the additional features
@@ -259,60 +319,5 @@ GLBINDING_API void setLogCallback(FunctionLogCallback callback);
 */
 GLBINDING_API void addContextSwitchCallback(ContextSwitchCallback callback);
 
-/**
-*  @brief
-*    Initializes the binding for the current active OpenGL context
-*
-*  @param[in] context
-*    The context handle of the context to initialize
-*  @param[in] functionPointerResolver
-*    A function pointer to resolve binding functions for this context
-*  @param[in] useContext
-*    Whether to set the context active (\a useContext = `true`) after the initialization
-*  @param[in] resolveFunctions (optional)
-*    Whether to resolve function pointers lazily (\a resolveFunctions = `false`) or immediately
-*
-*  @remark
-*    A functionPointerResolver with value 'nullptr' will get initialized with the function
-*    pointer from the initial thread.
-*/
-GLBINDING_API void initialize(ContextHandle context, glbinding::GetProcAddress functionPointerResolver, bool useContext = true, bool resolveFunctions = true);
 
-/**
-*  @brief
-*    Update the current context state in glbinding
-*
-*  @remark
-*    This function queries the driver for the current OpenGL context
-*/
-GLBINDING_API void useCurrentContext();
-
-/**
-*  @brief
-*    Update the current context state in glbinding
-*
-*  @param[in] context
-*    The context handle of the context to set current
-*/
-GLBINDING_API void useContext(ContextHandle context);
-
-/**
-*  @brief
-*    Removes the current context from the state of glbinding
-*
-*  @remark
-*    This function queries the driver for the current OpenGL context
-*/
-GLBINDING_API void releaseCurrentContext();
-
-/**
-*  @brief
-*    Removes the current context from the state of glbinding
-*
-*  @param[in] context
-*    The context handle of the context to remove
-*/
-GLBINDING_API void releaseContext(ContextHandle context);
-
-
-} // namespace glbinding
+} // namespace glbinding
\ No newline at end of file
